Scriptname SSOStartsScript extends Quest

; Marker to teleport PC to
ObjectReference property CryptMarker auto

; Options for Egg Factory starts
; Chance of giving an ancient nord amulet of fertility
int property AmuletChance auto
; Type of Egg Factory pregnancy to induce if > 0
int property PregType auto
; Stage of Egg Factory pregnancy to skip to
int property PregStage auto
; If > 0, hit the PC with an growth event at start, induces labor if pregstage is high enough
int property InduceLabor auto

; Container to hold the PC's starting equipment
ObjectReference property StartingGearContainer auto

; Parent marker for other things we might want enabled
ObjectReference property SceneMarker auto

; The starting prisoner clothes
armor property ClothesPrisonerTunic auto
armor property ClothesPrisonerShoes auto

; If true, play the 1st-person wake up animation
int property RudeAwakening auto

; Properties related to the above
imagespacemodifier property SleepyTimeFadeIn auto
idle property wakeup auto

; Quest for the log
quest property trackerquest auto

; Stage to jump that quest to
int property trackerqueststage auto

; NPC to untie the player and marker to move them to
Objectreference property RescueNPC auto
Objectreference property RescueMarker auto

function AddStartingGear(actor victim)
	int itemcount = StartingGearContainer.GetNumItems()
	int i = itemcount;
		
	while(i >= 0)
		Form kForm = StartingGearContainer.GetNthForm(i)
		if(kForm)
			StartingGearContainer.RemoveItem(kForm,StartingGearContainer.GetItemCount(kForm),true,victim)
			if(kForm as armor)
				victim.equipitem(kForm,false,true)
			endif
		endif
		i -= 1
	endwhile
	
endfunction

Event OnUpdate()

	actor newvictim = game.getplayer()
	armor RitualAmulet = Game.GetFormFromFile(0x3B211, "eggfactory.esp") as armor
	quest ARTHLALRumorsOfWarQuest = Game.GetFormFromFile(0x7a334, "Alternate Start - Live Another Life.esp") as quest

    debug.trace("SSO: Enabling the scene marker.")
    SceneMarker.Enable()
    
    utility.wait(0.05)

    debug.trace("SSO: Stripping you naked.")
    newvictim.unequipall()
    newvictim.RemoveItem(ClothesPrisonerTunic,1,true)
    newvictim.RemoveItem(ClothesPrisonerShoes,1,true)
    
    debug.trace("SSO: Adding starting gear.")
    AddStartingGear(newvictim)
    
    if(utility.randomint(1,100) < AmuletChance)
        debug.trace("SSO: Adding special amulet.")
        newvictim.additem(RitualAmulet,1,true)
        newvictim.equipitem(RitualAmulet,false,true)
    endif
    
    if(pregtype > 0)
        debug.trace("SSO: knocking you up.")
        int handle = ModEvent.Create("EggFactory_Impregnate")
        if (handle)
            modevent.pushform(handle, newvictim)
            ModEvent.PushInt(handle, pregtype)
            ModEvent.PushInt(handle, pregstage)
            ModEvent.send(handle)
        endif
    endif
    

    
    utility.wait(0.05)
    
    debug.trace("SSO: Starting the main quest.")
    ARTHLALRumorsOfWarQuest.RegisterForSingleUpdate(0.25)
    
    debug.trace("SSO: Moving you to starting location.")
    newvictim.moveto(CryptMarker)
    
    if(RescueNPC != NONE && RescueMarker != NONE)
        RescueNPC.MoveTo(RescueMarker)
    endif
    ;game.forcethirdperson()
    
    if(RudeAwakening == 1)
        debug.trace("SSO: Rude awakening start.")
        Game.ForceFirstPerson()
        SleepyTimeFadeIn.Apply()
        newvictim.PlayIdle(WakeUp)
    endif
    
    if(InduceLabor > 0)
        utility.wait(2.0)
        debug.trace("SSO: Now push!")
        int lhandle = ModEvent.Create("EggFactory_RapidStart")
        if (lhandle)
            modevent.pushform(lhandle, newvictim)
            modevent.pushint(lhandle, InduceLabor)
            modevent.send(lhandle)
        endif
    endif
    
    if(trackerquest != none)
        debug.trace("SSO: Updating your journal.")
        trackerquest.setstage(trackerqueststage)
        
        utility.wait(10.0)
        debug.trace("SSO: Updating your journal again.")
        trackerquest.CompleteQuest()
    endif
    
EndEvent

